@@ -2,4 +2,4 @@
 #
 # SPDX-License-Identifier: Apache-2.0
 
-from reflekt.cli import cli  # noqa: F401
+__version__ = "0.2.17"  # Set by bumpversion
