@@ -3,7 +3,9 @@
 # SPDX-License-Identifier: Apache-2.0
 
 import copy
+import hashlib
 import json
+import os
 import shutil
 import subprocess
 from pathlib import Path
@@ -16,7 +18,8 @@ from loguru import logger
 from packaging.version import InvalidVersion
 from packaging.version import parse as parse_version
 
-from reflekt import constants
+import reflekt.tracking
+from reflekt import __version__, constants
 from reflekt.api_handler import ReflektApiHandler
 from reflekt.avo.plan import AvoPlan
 from reflekt.config import ReflektConfig
@@ -31,23 +34,31 @@ from reflekt.segment.schema import (  # TODO: Likely need a handler for these sc
 from reflekt.transformer import ReflektTransformer
 from reflekt.utils import segment_2_snake
 
+reflekt.tracking.initialize_tracking()
 
+if ReflektProject().exists:
+    if ReflektConfig().do_not_track:
+        reflekt.tracking.do_not_track()
+
+
+# Use main() + @main.command decorator so that CLI does not require 'poetry run' prefix
+# reference: https://stackoverflow.com/a/55065934
 @click.group()
-def cli():
+def main():
     logger.configure(**logger_config)
 
 
 @click.option(
     "--project-dir",
     "project_dir_str",
-    # default=".",
+    default=".",
     required=True,
-    help="Path where Reflekt project will be created. Defaults to current directory.",
+    help="Path where Reflekt project will be created. Default is the current directory.",
 )
-@click.command()
+@main.command()
 def init(project_dir_str: str) -> None:
     """Create a Reflekt project at the provide directory."""
-    project_dir = Path(project_dir_str).resolve()
+    project_dir = Path(project_dir_str).expanduser()
     project_name = click.prompt(
         "Enter your project name (letters, digits, underscore)", type=str
     )
@@ -113,7 +124,7 @@ def init(project_dir_str: str) -> None:
 
     if collect_config:
         plan_type_prompt = click.prompt(
-            f"What Analytics Governance tool do you use to manage your tracking plan(s)?"
+            f"What tracking plan tool do you use to manage your tracking plan(s)?"
             f"{constants.PLAN_INIT_STRING}"
             f"\nEnter a number",
             type=int,
@@ -137,11 +148,40 @@ def init(project_dir_str: str) -> None:
             )
             reflekt_config_obj[config_name]["access_token"] = access_token
         elif plan_type == "avo":
-            avo_end_msg = (
-                "You've selected Avo as your Analytics Governance tool which requires "
-                "additional setup steps. Please see the docs for additional guidance:\n"
-                "    https://reflekt-ci.notion.site/Connect-Reflekt-to-Avo-489158cf319f43c491470c54b37e3b13"  # noqa: E501
+            workspace_id = click.prompt(
+                "Enter your Avo workspace ID. See the Avo docs "
+                "(https://www.avo.app/docs/public-api/export-tracking-plan) on how to "
+                "find your workspace ID. This requires Avo API access "
+                "(https://www.avo.app/docs/public-api/export-tracking-plan). Contact "
+                "Avo support for access if you do not have it.",
+                type=str,
+                hide_input=True,
             )
+            reflekt_config_obj[config_name]["workspace_id"] = workspace_id
+            service_account_name = click.prompt(
+                "Enter your Avo service account name. See the Avo docs "
+                "(https://www.avo.app/docs/public-api/authentication#creating-service-accounts) "  # noqa: E501
+                "on creating your service account credentials. This requires Avo API "
+                "access (https://www.avo.app/docs/public-api/export-tracking-plan). "
+                "Contact Avo support for access if you do not have it.",
+                type=str,
+                hide_input=True,
+            )
+            reflekt_config_obj[config_name][
+                "service_account_name"
+            ] = service_account_name
+            service_account_secret = click.prompt(
+                "Enter your Avo service account secret. See the Avo docs "
+                "(https://www.avo.app/docs/public-api/authentication#creating-service-accounts) "  # noqa: E501
+                "on creating your service account credentials. This requires Avo API "
+                "access (https://www.avo.app/docs/public-api/export-tracking-plan). "
+                "Contact Avo support for access if you do not have it.",
+                type=str,
+                hide_input=True,
+            )
+            reflekt_config_obj[config_name][
+                "service_account_secret"
+            ] = service_account_secret
 
         # TODO - Enable support for other CDPs below as developed
         # elif plan_type == "rudderstack":
@@ -276,12 +316,25 @@ def init(project_dir_str: str) -> None:
         f"        Template dbt package with sources, models, and docs for all events in tracking plan."  # noqa: E501
     )
 
-    if plan_type == "avo":
-        logger.info("")  # Terminal newline
-        logger.info(avo_end_msg)
+    reflekt.tracking.track_event(
+        "project_created",
+        properties={
+            "project_id": hashlib.md5(project_name.encode("utf-8")).hexdigest(),
+            "ci": os.getenv("CI") if os.getenv("CI") is True else False,
+            "cdp_type": cdp,
+            "warehouse_type": warehouse,
+            "plan_type": plan_type,
+        },
+        context={
+            "app": {
+                "name": "reflekt",
+                "version": __version__,
+            }
+        },
+    )
 
 
-@click.command()
+@main.command()
 @click.option(
     "-n",
     "--name",
@@ -317,8 +370,26 @@ def new(plan_name: str) -> None:
     logger.info("")  # Terminal newline
     logger.success(f"Created Reflekt tracking plan '{plan_name}'")
 
+    reflekt.tracking.track_event(
+        "plan_created",
+        properties={
+            "project_id": hashlib.md5(ReflektProject().name.encode("utf-8")).hexdigest(),
+            "plan_id": hashlib.md5(plan_name.encode("utf-8")).hexdigest(),
+            "ci": os.getenv("CI") if os.getenv("CI") is True else False,
+            "cdp_type": ReflektConfig().cdp_name,
+            "warehouse_type": ReflektConfig().warehouse_type,
+            "plan_type": ReflektConfig().plan_type,
+        },
+        context={
+            "app": {
+                "name": "reflekt",
+                "version": __version__,
+            }
+        },
+    )
 
-@click.command()
+
+@main.command()
 @click.option(
     "-n",
     "--name",
@@ -339,12 +410,17 @@ def new(plan_name: str) -> None:
 )
 def pull(plan_name: str, raw: bool, avo_branch: str) -> None:
     """Generate tracking plan as code using the Reflekt schema."""
-    api = ReflektApiHandler().get_api(avo_branch=avo_branch)
+    api = ReflektApiHandler().get_api()
     config = ReflektConfig()
     logger.info(
         f"Searching {titleize(config.plan_type)} for tracking plan '{plan_name}'"
     )
-    plan_json = api.get(plan_name)
+
+    if api.type == "segment":  # Segment supports multiple plans, no branches
+        plan_json = api.get(plan_name)
+    elif api.type == "avo":  # Avo supports one plan, multiple branches
+        plan_json = api.get(avo_branch)
+
     logger.info(f"Found tracking plan '{plan_name}'")
 
     if raw:
@@ -370,6 +446,24 @@ def pull(plan_name: str, raw: bool, avo_branch: str) -> None:
         logger.info("")  # Terminal newline
         logger.success(f"Built Reflekt tracking plan '{plan_name}'")
 
+    reflekt.tracking.track_event(
+        "plan_pulled",
+        properties={
+            "project_id": hashlib.md5(ReflektProject().name.encode("utf-8")).hexdigest(),
+            "plan_id": hashlib.md5(plan_name.encode("utf-8")).hexdigest(),
+            "ci": os.getenv("CI") if os.getenv("CI") is True else False,
+            "cdp_type": ReflektConfig().cdp_name,
+            "warehouse_type": ReflektConfig().warehouse_type,
+            "plan_type": ReflektConfig().plan_type,
+        },
+        context={
+            "app": {
+                "name": "reflekt",
+                "version": __version__,
+            }
+        },
+    )
+
 
 @click.option(
     "-n",
@@ -408,23 +502,45 @@ def pull(plan_name: str, raw: bool, avo_branch: str) -> None:
         "traits from a tracking plan."
     ),
 )
-@click.command()
-def push(plan_name, dry, updates, removes) -> None:
+@click.option(
+    "-t",
+    "--target",
+    "target",
+    type=str,
+    multiple=True,
+    required=False,
+    help=(
+        "Syncs the plan provided in the --name arg to an alternative plan name provided "
+        "the --target arg. Useful when managing staging vs production tracking plans."
+    ),
+)
+@main.command()
+def push(plan_name, dry, updates, removes, target) -> None:
     """Sync tracking plan to CDP or Analytics Governance tool."""
     api = ReflektApiHandler().get_api()
     config = ReflektConfig()
+    plan_dir = ReflektProject().project_dir / "tracking-plans" / plan_name
+    # Set defaults
+    reflekt_plan_name = plan_name
+    api_plan_name = plan_name
 
     if api.type.lower() in ["avo"]:
         logger.error(f"'reflekt push' not supported for {titleize(api.type)}.")
         raise click.Abort()
 
-    plan_dir = ReflektProject().project_dir / "tracking-plans" / plan_name
-
-    # Check for incompatible arguments
-    if updates != () and removes != ():
+    if updates != () and removes != ():  # Check for incompatible arguments
         logger.error("--update and --remove arguments cannot be combined!")
         raise SystemExit(1)
 
+    if target != ():
+        if len(target) > 1:
+            logger.error("--target only accepts one argument")
+            raise SystemExit(1)
+        else:
+            target_name = target[0]
+    else:
+        target_name = None
+
     if updates != ():
         # Determine what needs to be updated based on --update arg
         update_events = tuple(
@@ -436,18 +552,31 @@ def push(plan_name, dry, updates, removes) -> None:
         update_group_traits = tuple(
             update for update in updates if update == "group-traits"
         )
-        # Get the existing tracking plan that will be updated
-        logger.warning(
+
+        if target_name is not None:
+            api_plan_name = target_name
+            logger.warning(
+                f"--target flag detected. Syncing Reflekt plan {reflekt_plan_name} to "
+                f"{titleize(config.plan_type)} tracking plan '{api_plan_name}'"
+            )
+
+        logger.warning(  # Get the existing tracking plan that will be updated
             f"--update flag detected. Searching {titleize(config.plan_type)} for "
-            f"existing tracking plan '{plan_name}'"
+            f"existing tracking plan '{api_plan_name}' to update."
         )
-        existing_plan_json = api.get(plan_name)  # Get the existing plan
+
+        existing_plan_json = api.get(api_plan_name)  # Get the existing plan
         logger.info("")  # Terminal newline
-        logger.info(f"Found existing tracking plan '{plan_name}'")
+        logger.info(
+            f"Found existing {titleize(config.plan_type)} tracking plan "
+            f"'{api_plan_name}'"
+        )
 
         # Load a Reflekt tracking, only including items from the --update arg
         logger.info("")  # Terminal newline
-        logger.info(f"Updating tracking plan {plan_name}")
+        logger.info(
+            f"Loading Reflekt tracking plan {reflekt_plan_name} and specified events."
+        )
         loader = ReflektLoader(
             plan_dir=plan_dir,
             parse_all=False,
@@ -497,8 +626,11 @@ def push(plan_name, dry, updates, removes) -> None:
         sync_plan_json["tracking_plan"]["rules"]["events"] = sync_events
         cdp_plan = sync_plan_json
 
+        if target and str.lower(config.plan_type) == "segment":
+            cdp_plan["tracking_plan"]["display_name"] = api_plan_name
+
     elif removes != ():
-        # Determine what needs to be removed based on --remvoe arg
+        # Determine what needs to be removed based on --remove arg
         remove_events = tuple(
             remove
             for remove in removes
@@ -510,13 +642,22 @@ def push(plan_name, dry, updates, removes) -> None:
         remove_group_traits = tuple(
             remove for remove in removes if remove == "group-traits"
         )
+
+        if target_name is not None:
+            api_plan_name = target_name
+            logger.warning(
+                f"--target flag detected. Syncing Reflekt plan {reflekt_plan_name} to "
+                f"{titleize(config.plan_type)} tracking plan '{api_plan_name}'"
+            )
+
         # Get the existing plan that will have events/traits removed
         remove_event_str = ", ".join("'" + event + "'" for event in remove_events)
         logger.warning(
             f"--remove flag detected. Removing event(s): {remove_event_str}, from "
-            f"tracking plan {plan_name} in {titleize(config.plan_type)}"
+            f"{titleize(config.plan_type)} tracking plan '{api_plan_name}'"
         )
-        existing_plan_json = api.get(plan_name)
+
+        existing_plan_json = api.get(api_plan_name)
         existing_events = existing_plan_json["rules"]["events"]
         sync_events = []  # Events to sync
 
@@ -539,9 +680,8 @@ def push(plan_name, dry, updates, removes) -> None:
             ] = []
 
     else:
+        # Sync the plan as specified by the --name arg
         logger.info(f"Loading Reflekt tracking plan '{plan_name}'")
-
-        # Load the plan using the ORIGINAL name
         loader = ReflektLoader(
             plan_dir=plan_dir,
         )
@@ -550,8 +690,18 @@ def push(plan_name, dry, updates, removes) -> None:
         plan_updates_json = transformer.build_cdp_plan()
         cdp_plan = plan_updates_json
 
+        if target_name is not None:
+            api_plan_name = target_name
+            logger.warning(
+                f"--target flag detected. Syncing Reflekt plan {reflekt_plan_name} to "
+                f"{titleize(config.plan_type)} tracking plan '{api_plan_name}'"
+            )
+
+            if str.lower(config.plan_type) == "segment":
+                cdp_plan["tracking_plan"]["display_name"] = api_plan_name
+
     if dry:
-        payload = api.sync(plan_name, cdp_plan, dry=True)
+        payload = api.sync(api_plan_name, cdp_plan, dry=True)
         logger.info("")  # Terminal newline
         logger.info(
             f"[DRY RUN] The following JSON would be sent to {transformer.plan_type}"
@@ -560,17 +710,35 @@ def push(plan_name, dry, updates, removes) -> None:
     else:
         logger.info("")  # Terminal newline
         logger.info(
-            f"Syncing converted tracking plan '{plan_name}' to "
-            f"{titleize(config.plan_type)}"
+            f"Syncing Reflekt tracking plan '{reflekt_plan_name}' to "
+            f"{titleize(config.plan_type)} tracking plan '{api_plan_name}'"
         )
 
-        api.sync(plan_name, cdp_plan)
+        api.sync(api_plan_name, cdp_plan)
         logger.info("")  # Terminal newline
         logger.success(
-            f"Synced Reflekt tracking plan '{plan_name}' to "
-            f"{titleize(config.plan_type)}"
+            f"Synced Reflekt tracking plan '{reflekt_plan_name}' to "
+            f"{titleize(config.plan_type)} tracking plan '{api_plan_name}'"
         )
 
+    reflekt.tracking.track_event(
+        "plan_pushed",
+        properties={
+            "project_id": hashlib.md5(ReflektProject().name.encode("utf-8")).hexdigest(),
+            "plan_id": hashlib.md5(plan_name.encode("utf-8")).hexdigest(),
+            "ci": os.getenv("CI") if os.getenv("CI") is True else False,
+            "cdp_type": ReflektConfig().cdp_name,
+            "warehouse_type": ReflektConfig().warehouse_type,
+            "plan_type": ReflektConfig().plan_type,
+        },
+        context={
+            "app": {
+                "name": "reflekt",
+                "version": __version__,
+            }
+        },
+    )
+
 
 @click.option(
     "-s",
@@ -589,14 +757,14 @@ def push(plan_name, dry, updates, removes) -> None:
     required=True,
     help="Name of tracking plan to be tested (specified in kebab-case).",
 )
-@click.command()
+@main.command()
 def test(plan_name, selection) -> None:
     """Test tracking plan schema for naming, data types, and metadata."""
     plan_dir = ReflektProject().project_dir / "tracking-plans" / plan_name
     logger.info(f"Testing Reflekt tracking plan '{plan_name}'")
 
     if selection != ():
-        # Determine what needs to be updated based on --update arg
+        # Determine what needs to be test based on --select arg
         selected_events = tuple(
             selected
             for selected in selection
@@ -619,10 +787,29 @@ def test(plan_name, selection) -> None:
         )
     else:
         ReflektLoader(plan_dir=plan_dir)
-    # If no errors are thrown, passed tests
+
+    # If no errors are thrown by ReflektLoader, passed tests
     logger.info("")
     logger.success("Test complete. No errors.")
 
+    reflekt.tracking.track_event(
+        "plan_tested",
+        properties={
+            "project_id": hashlib.md5(ReflektProject().name.encode("utf-8")).hexdigest(),
+            "plan_id": hashlib.md5(plan_name.encode("utf-8")).hexdigest(),
+            "ci": os.getenv("CI") if os.getenv("CI") is True else False,
+            "cdp_type": ReflektConfig().cdp_name,
+            "warehouse_type": ReflektConfig().warehouse_type,
+            "plan_type": ReflektConfig().plan_type,
+        },
+        context={
+            "app": {
+                "name": "reflekt",
+                "version": __version__,
+            }
+        },
+    )
+
 
 @click.option(
     "--tag",
@@ -680,7 +867,7 @@ def test(plan_name, selection) -> None:
     required=True,
     help="Tracking plan name in your Reflekt project.",
 )
-@click.command()
+@main.command()
 def dbt(
     plan_name,
     events,
@@ -817,9 +1004,7 @@ def dbt(
             )
             if create_tag:
                 tag_str = click.prompt(
-                    "Git tag",
-                    type=str,
-                    default=f"v{str(version)}__{pkg_name}",
+                    "Git tag", type=str, default=f"v{str(version)}__{pkg_name}"
                 )
             else:
                 tag_str = None
@@ -831,52 +1016,52 @@ def dbt(
             if plan_type == "avo":
                 rel_avo_json_path = ".reflekt/avo/avo.json"
                 subprocess.call(
-                    args=[
-                        git_executable,
-                        "add",
-                        rel_pkg_path,
-                        rel_avo_json_path,
-                    ],
+                    args=[git_executable, "add", rel_pkg_path, rel_avo_json_path],
                     cwd=project_dir,
                 )
             else:
                 subprocess.call(
-                    args=[
-                        git_executable,
-                        "add",
-                        rel_pkg_path,
-                    ],
+                    args=[git_executable, "add", rel_pkg_path],
                     cwd=project_dir,
                 )
 
             subprocess.call(
-                args=[
-                    git_executable,
-                    "commit",
-                    "-m",
-                    commit_str,
-                ],
+                args=[git_executable, "commit", "-m", commit_str],
                 cwd=project_dir,
             )
 
         if tag_str is not None:
             subprocess.call(
-                args=[
-                    git_executable,
-                    "tag",
-                    tag_str,
-                ],
+                args=[git_executable, "tag", tag_str],
                 cwd=project_dir,
             )
 
+    reflekt.tracking.track_event(
+        "dbt_package_built",
+        properties={
+            "project_id": hashlib.md5(ReflektProject().name.encode("utf-8")).hexdigest(),
+            "plan_id": hashlib.md5(plan_name.encode("utf-8")).hexdigest(),
+            "ci": os.getenv("CI") if os.getenv("CI") is True else False,
+            "cdp_type": ReflektConfig().cdp_name,
+            "warehouse_type": ReflektConfig().warehouse_type,
+            "plan_type": ReflektConfig().plan_type,
+        },
+        context={
+            "app": {
+                "name": "reflekt",
+                "version": __version__,
+            }
+        },
+    )
+
 
 # Add CLI commands to CLI group
-cli.add_command(init)
-cli.add_command(new)
-cli.add_command(pull)
-cli.add_command(push)
-cli.add_command(test)
-cli.add_command(dbt)
+main.add_command(init)
+main.add_command(new)
+main.add_command(pull)
+main.add_command(push)
+main.add_command(test)
+main.add_command(dbt)
 
 
 # Used for CLI debugging
@@ -892,19 +1077,21 @@ if __name__ == "__main__":
     # pull(["-n", "my-avo-plan", "--avo-branch", "staging"])
 
     # ----- SEGMENT -----
-    pull(["-n", "my-segment-plan"])
+    # pull(["-n", "my-segment-plan"])
     # pull(["-n", "my-segment-plan"], "--raw")
+
     # push(["-n", "my-segment-plan"])
     # push(["-n", "my-segment-plan", "--dry"])
+    # push(["-n", "my-segment-plan", "--target", "my-segment-plan-qa"])
     # push(["-n", "my-segment-plan", "-u", "new-event"])
     # push(["-n", "my-segment-plan", "-r", "new-event"])
     # push(["-n", "test-plan", "-u", "user-traits"])
 
     # ----- REFLEKT -----
-    # test(["-n", "my-segment-plan"])
+    test(["-n", "my-segment-plan"])
     # test(["-n", "my-segment-plan", "-e", "order-completed"])
 
-    # dbt(["-n", "my-segment-plan"])
-    # dbt(["-n", "my-segment-plan", "-e", "order-completed")]
-    # dbt(["-n", "my-segment-plan", "-e", "user-traits"])
-    # dbt(["-n", "my-segment-plan", "-e", "group-traits"])
+    # dbt(["-n", "my-segment-plan", "-s", "my_app_web"])
+    # dbt(["-n", "my-segment-plan", "-s", "my_app_web", "-e", "order-completed")]
+    # dbt(["-n", "my-segment-plan", "-s", "my_app_web", "-e", "user-traits"])
+    # dbt(["-n", "my-segment-plan", "-s", "my_app_web", "-e", "group-traits"])
