@@ -6,7 +6,7 @@ TITLE_CASE_RE = r"[A-Z][a-z]+"
 CAMEL_CASE_RE = r"(^[a-z]|[A-Z])[a-z]*"
 SNAKE_CASE_RE = r"^[a-z._]+$"
 
-REFLEKT_TEMPLATE_COLUMNS = [
+REFLEKT_INJECTED_COLUMNS = [  # Columns Reflekt injects when templating
     "source_schema",
     "source_table",
     "tracking_plan",
@@ -14,9 +14,21 @@ REFLEKT_TEMPLATE_COLUMNS = [
     "call_type",
 ]
 
-REFLEKT_RESERVED_COLUMNS = [
+# Columns reserved by Reflekt templater. If found in table, prefix with underscore (_)
+REFLEKT_TEMPLATED_COLUMNS = [
+    "id",
     "user_id",
     "anonymous_id",
+    "user_id",
+    "group_id",
+    "page_id",
+    "screen_id",
+    "event_id",
+    "source_schema",
+    "source_table",
+    "tracking_plan",
+    "event_name",
+    "call_type",
 ]
 
 PLANS = [
@@ -24,7 +36,6 @@ PLANS = [
     "avo",
     # "rudderstack",
     # "snowplow",
-    # "iteratively",
 ]
 
 PLAN_INIT_STRING = (
@@ -32,7 +43,6 @@ PLAN_INIT_STRING = (
     "\n[2] Avo"
     # "\n[3] Rudderstack"
     # "\n[4] Snowplow"
-    # "\n[5] Iteratively"
 )
 
 PLAN_MAP = {
@@ -40,7 +50,6 @@ PLAN_MAP = {
     "2": "avo",
     # "3": "rudderstack",
     # "4": "snowplow",
-    # "5": "iteratively",
 }
 
 CDPS = [
